<?php
/**
 * @file
 * Cache backend include for the White Label module.
 */

/**
 * Defines a White Label cache implementation.
 *
 * To use this functionality, the following needs to be added to settings.php
 *
 * @code
 * $conf['cache_backends'][] = 'sites/all/modules/whitelabel/cache/whitelabel_cache.inc';
 * $conf['cache_class_cache_page'] = 'WhitelabelCache';
 * @endcode
 */
class WhitelabelCache extends DrupalDatabaseCache implements DrupalCacheInterface {

  /**
   * {@inheritdoc}
   */
  function set($cid, $data, $expire = CACHE_PERMANENT) {
    $cid = $this->whitelabel_caching_alter_cid() . $cid;
    parent::set($cid, $data, $expire);
  }

  /**
   * {@inheritdoc}
   */
  function getMultiple(&$cids) {
    if (is_array($cids)) {
      foreach ($cids as $key => $cid) {
        $cids[$key] = $this->whitelabel_caching_alter_cid() . $cid;
      }
    }
    return parent::getMultiple($cids);
  }

  /**
   * Determines a prefix for the page cache $cid based on white label user.
   *
   * @return string
   *   The $cid prefix
   */
  protected function whitelabel_caching_alter_cid() {
    require_once dirname(__FILE__) . '/../whitelabel.module';

    $return = '';

    if (!empty($_SESSION['whitelabel']['hash'])) {
      $return = $_SESSION['whitelabel']['hash'] . ':';
    }
    elseif ($wl = whitelabel_get_whitelabel_from_url()) {
      $return = $wl['hash'] . ':';
    }

    return $return;
  }

}
