<?php
/**
 * @file
 * Adds Views fields for white labels.
 */

/**
 * Implements hook_views_data().
 */
function whitelabel_views_data() {
  $data['whitelabel']['table']['group'] = t('White label');

  // This table references the {user} table. The declaration below creates an
  // 'implicit' relationship to the user table, so that when 'user' is the base
  // table, the fields are automatically available.
  $data['whitelabel']['table']['join'] = array(
    // Index this array by the table name to which this table refers.
    // 'left_field' is the primary key in the referenced table.
    // 'field' is the foreign key in this table.
    'users' => array(
      'left_field' => 'uid',
      'field' => 'uid',
    ),
  );

  $data['whitelabel']['uid'] = array(
    'title' => t('White label user uid'),
    'help' => t('The user associated with the white label'),
    'relationship' => array(
      'base' => 'users',
      'field' => 'uid',
      'handler' => 'views_handler_relationship',
      'label' => t('White label user uid'),
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_user_name',
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'field' => array(
      'handler' => 'views_handler_field_user',
    ),
  );

  $data['whitelabel']['site_name'] = array(
    'title' => t('Whitelabel name'),
    'help' => t('The name of a white labeled site.'),
    'field' => array(
      'handler' => 'whitelabel_field_handler',
      'click sortable' => TRUE, // This is use by the table display plugin.
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_string',
    ),
  );

  $data['whitelabel']['site_logo'] = array(
    'title' => t('Whitelabel logo'),
    'help' => t('The logo of a white labeled site.'),
    'field' => array(
      'handler' => 'whitelabel_field_handler_logo',
    ),
  );

  return $data;
}
